<?php
/**
* MyPHPCommander: The management tool
* Copyright (C) 2005-2006  Martin Schrder

* This program is free software; you can redistribute it and/or modify it under
* the terms of the GNU General Public License as published by the
* Free Software Foundation; either version 2 of the License, or (at your option)
* any later version.

* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU General Public License for more details.

* You should have received a copy of the GNU General Public License
* along with this program;
* if not, see http://www.gnu.org/licenses/gpl.html
**/

//Load configuration file
$gl_config=parse_ini_file('system/config.ini',true);
$gl_language=@parse_ini_file('system/lang/'.$gl_config['general']['language'].'.lng',true);

//SESSION
if($gl_config['general']['SessionHandler']!='php')
{
  require_once 'system/lib/session_'.$gl_config['general']['SessionHandler'].'.php';
  $gl_session=new CSession;
  session_set_save_handler( array(&$gl_session,"open"),
                            array(&$gl_session,"close"),
                            array(&$gl_session,"read"),
                            array(&$gl_session,"write"),
                            array(&$gl_session,"destroy"),
                            array(&$gl_session,"gc"));
}

$gl_root=dirname(__FILE__).'/';
$gl_root_html=dirname('/');

require_once 'system/constants.php';
require_once 'system/functions.php';
require_once 'system/PluginBase.php';
require_once 'system/lib/user.php';

//Start session
session_start();

//Send header to avoid caching
header("Cache-Control: no-cache, must-revalidate");
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");

$gl_current_user=new CUser;

//If this is the first call, initialize the list of loaded Plugins
if(!isset($_SESSION['LoadedPlugins'])||!is_array($_SESSION['LoadedPlugins']))
{
  $_SESSION['LoadedPlugins']=array($gl_config['general']['PermanentPlugin']);
}

//If this is the first call, initialize the console or clear the console
if(!isset($_SESSION['ConsoleEntries'])||!is_array($_SESSION['ConsoleEntries'])||isset($_REQUEST['ClearLog']))
{
  $_SESSION['ConsoleEntries']=array();
  AddConsoleEntry('info','MyPHPCommander v'.MYPHPCOMMANDER_VERSION.' Copyright &copy; 2005-2006 by Martin Schr&ouml;der (distributed under the terms of the GNU General Public License)');
}

//Close Pluginwindow
if(isset($_GET['UnloadPlugin']))
{
  UnloadPlugin($_GET['UnloadPlugin']);
}

//Open new Pluginwindow
if(isset($_GET['LoadPlugin']))
{
  LoadPlugin($_GET['LoadPlugin']);
}

//Load the Plugins
$gl_LoadedPluginsObjects=array();
foreach($_SESSION['LoadedPlugins'] as $key => $LoadedPlugin)
{
  if(!is_file('plugins/'.$LoadedPlugin.'/program.php'))
  {
    AddConsoleEntry('error','Plugin can\'t be loaded: '.$LoadedPlugin.' File not found');
    UnloadPlugin($LoadedPlugin);
    continue;
  }
  include 'plugins/'.$LoadedPlugin.'/program.php';
  $classname='Plugin'.$LoadedPlugin;
  if(!class_exists($classname))
  {
    AddConsoleEntry('error','Plugin can\'t be loaded: '.$LoadedPlugin.' Class not found');
    UnloadPlugin($LoadedPlugin);
    continue;
  }
  $gl_LoadedPluginsObjects[$key]=new $classname;

  if($gl_current_user->RightsPlugin($LoadedPlugin)<$gl_LoadedPluginsObjects[$key]->reqRight)
    unset($gl_LoadedPluginsObjects[$key]);
}

//Load the required libraries
foreach($gl_LoadedPluginsObjects as $LoadedPluginObject)
{
  foreach($LoadedPluginObject->libs as $lib)
  {
    if(!is_file('system/lib/'.$lib.'.php'))
    {
      UnloadPlugin($LoadedPluginObject->name);
      AddConsoleEntry('error','Plugin "'.$LoadedPluginObject->name.'" needs a library: '.$lib);
    }
    else
      include_once 'system/lib/'.$lib.'.php';
  }
}

if(isset($_GET['core']['mode']))
{
  if($_GET['core']['mode']=='dataonly')
  {
    foreach($gl_LoadedPluginsObjects as $object)
    {
      if($object->name==$_GET['core']['source'])
      {
        header('Content-type: text/javascript');
        $object->OutpJSData();
        break;
      }
    }
    session_write_close();
    exit;
  }
}

/*******************************************************************************
*** Output *********************************************************************
*******************************************************************************/
//First (Headers, sent files, ...)
foreach($gl_LoadedPluginsObjects as $LoadedPluginObject)
{
  $LoadedPluginObject->OutpFirst();
  echo "\n";
}

//HTML
echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/strict.dtd">';
echo '<html>';
echo '<head>';
echo '<title>MyPHPCommander v'.MYPHPCOMMANDER_VERSION.'</title>';
?>
<link rel="stylesheet" type="text/css" href="styles/compiled.css">
<script type="text/javascript" src="system/PHP_Serializer.js">
</script>
<script type="text/javascript" src="system/javascript.js">
</script>
<?php
//Header
foreach($gl_LoadedPluginsObjects as $LoadedPluginObject)
{
  $LoadedPluginObject->OutpHeader();
  echo "\n";
}
?>
</head>
<body>
<?php
//Taskbar
echo '<div id="shell_taskbar">';
foreach($gl_LoadedPluginsObjects as $LoadedPluginObject)
{
  echo '<div class="taskbaricon" id="taskicon_'.$LoadedPluginObject->name.'" onClick="PluginSetForeground(\''.$LoadedPluginObject->name.'\');">';
  echo '<img src="'.$LoadedPluginObject->pluginpathhtml.$LoadedPluginObject->icon_small.'" alt="'.$LoadedPluginObject->name.'" /> '.str_replace(' ','&nbsp;',$LoadedPluginObject->fullname).'</div>';
  echo "\n";
}
if(false)
{
  echo '<div class="taskbar_user"></div>';
}
echo '<br style="clear: left"/>';
echo '</div>';

//"Windows"
echo '<div id="shell_windowcontainer">';

//Body
foreach($gl_LoadedPluginsObjects as $LoadedPluginObject)
{
  echo '<div class="plugin_container" id="plugin_'.$LoadedPluginObject->name.'">';
  echo '<div class="plugin_title">';
  echo '<div class="plugin_title_name">';
  echo '<img src="'.$LoadedPluginObject->pluginpathhtml.$LoadedPluginObject->icon_small.'" alt="'.$LoadedPluginObject->name.'" /> ';
  echo $LoadedPluginObject->fullname;
  echo '</div>';
  echo '<div class="plugin_title_actions">';
  if($LoadedPluginObject->name!=$gl_config['general']['PermanentPlugin'])
    echo '<a href="index.php?UnloadPlugin='.$LoadedPluginObject->name.'"><img src="icons/system_close.png" alt=""/></a>';
  echo '</div>';
  echo '</div>';
  echo '<div class="plugin_menu">';
  $LoadedPluginObject->OutpMenu();
  echo '</div>';
  echo '<div class="plugin_body">';
  $LoadedPluginObject->OutpBody();
  echo '</div>';
  echo '</div>';
  echo "\n";
}
echo '</div>';

//Console
echo '<div id="shell_console" ondblclick="location.href=\'index.php?ClearLog=1\'">';
$console_r=$_SESSION['ConsoleEntries'];
krsort($console_r);
foreach($console_r as $entry)
{
  switch($entry['type'])
  {
  case 'error':
    echo '<img src="icons/console_error.png" class="console_image" alt="Error"/> ';
    break;
  case 'info':
    echo '<img src="icons/console_info.png" class="console_image" alt="Info"/> ';
    break;
  case 'warning':
    echo '<img src="icons/console_warning.png" class="console_image" alt="Warning"/> ';
    break;
  }
  echo $entry['text'].'<br/>';
}
echo '</div>';
?>
<script type="text/javascript">
PluginSetForeground(readCookie('lastPlugin'));
</script>
</body>
</html>
<?php
session_write_close();
?>
