<?php
/*original: XMLParser by raphael at schwarzschmid dot de, altered by Martin Schrder*/
class CXML
{
  var $filename;
  var $xml;
  var $data;

  function Read($xml_file)
  {
    $this->filename = $xml_file;
    $this->xml = xml_parser_create();
    xml_set_object($this->xml, $this);
    xml_set_element_handler($this->xml, '_startHandler', '_endHandler');
    xml_set_character_data_handler($this->xml, '_dataHandler');
    $res=$this->_parse($xml_file);
    xml_parser_free($this->xml);
    return $res;
  }

  function Write($xml_file='')
  {
    if($xml_file=='')
      $xml_file=$this->filename;

    $output=$this->_output($this->data,-1);

    if (!(@$fp = fopen($xml_file, 'w')))
      return false;

    fwrite($fp,$output);
    fclose($fp);
  }

  function _output($data,$depth)
  {
    $outp='';
    $spac='';
    for($i=0;$i<=$depth;$i++)
      $spac.=' ';
    foreach($data as $datum)
    {
      $attributes='';
      if(isset($datum['attributes']))
      {
        foreach($datum['attributes'] as $name => $value)
        {
          $attributes.=' '.$name.'="'.$this->_entities($value).'"';
        }
      }
      if(isset($datum['child']))
      {
        $outp.=$spac.'<'.$datum['name'].$attributes.'>';
        $outp.="\n";
        $outp.=$this->_output($datum['child'],$depth+1);
        $outp.=$spac.'</'.$datum['name'].'>';
        $outp.="\n";
      }
      else if(isset($datum['content']))
      {
        $outp.=$spac.'<'.$datum['name'].$attributes.'>';
        $outp.=$this->_entities($datum['content']);
        $outp.='</'.$datum['name'].'>';
        $outp.="\n";
      }
      else
      {
        $outp.=$spac.'<'.$datum['name'].$attributes.'/>';
        $outp.="\n";
      }
    }

    return $outp;
  }

  function _parse($xml_file)
  {
    if (!(@$fp = fopen($xml_file, 'r')))
      return false;

    $bytes_to_parse = 512;

    while ($data = fread($fp, $bytes_to_parse))
    {
      $parse = xml_parse($this->xml, $data, feof($fp));

      if (!$parse)
      {
        echo sprintf("XML error: %s at line %d",
        xml_error_string(xml_get_error_code($this->xml)),
        xml_get_current_line_number($this->xml));
        return false;
      }
    }
    return true;
  }

  function _startHandler($parser, $name, $attributes)
  {
    $data['name'] = strtolower($name);
    if ($attributes)
    {
      $attributes_c=array();
      foreach($attributes as $key => $attribute)
      {
        $attributes_c[strtolower($key)]=$attribute;
      }
      $data['attributes'] = $attributes_c;
    }
    $this->data[] = $data;
  }

  function _dataHandler($parser, $data)
  {
    if ($data = trim($data))
    {
      $index = count($this->data) - 1;
      // begin multi-line bug fix (use the .= operator)
      if(!isset($this->data[$index]['content']))
      $this->data[$index]['content']="";
      $this->data[$index]['content'] .= $data;
      // end multi-line bug fix
    }
  }

  function _endHandler($parser, $name)
  {
    if (count($this->data) > 1)
    {
      $data = array_pop($this->data);
      $index = count($this->data) - 1;
      $this->data[$index]['child'][] = $data;
    }
  }

  function _entities($string)
  {
    return preg_replace('/([^\x09\x0A\x0D\x20-\x7F]|[\x21-\x2F]|[\x3A-\x40]|[\x5B-\x60])/e'
           , '"&#".ord("$0").";"', $string);
  }
}
?>
